/*
# Copyright 2006, Revolution Linux Inc.
#
# $Id$
#
# Authors : Francis Giraldeau <francis.giraldeau@revolutionlinux.com>
#
# This file is part of the MILLE-XTERM project.
#
#               http://www.revolutionlinux.com/mille-xterm/
#               http://www.mille.ca/
#
# This program is covered by the GNU General Public License.
# See the COPYING file in the top-level MILLE-XTERM directory.
#
# -------------------------------------------------------------------------
*/

#include "mxsoundapplet.h"

#include <iostream>

#include <qlabel.h>
#include <qfileinfo.h>
#include <qprocess.h>
#include <qstringlist.h>
#include <qpopupmenu.h>
#include <qdir.h>

#include <ksystemtray.h>
#include <kmessagebox.h>
#include <kiconloader.h>
#include <kpopupmenu.h>
#include <klocale.h>
#include <kaction.h>
#include <kaboutapplication.h>

using namespace std;

mxsoundapplet::mxsoundapplet( KAboutData *about)
    : KSystemTray( 0, "mxsoundapplet" )
{
    m_about_data = about;
    KIconLoader *iconLoader = new KIconLoader();
    QPixmap icon = iconLoader->loadIcon("kmix", KIcon::Small);
    setPixmap(icon);

    setCaption("Mille-xterm sound applet");
    KPopupMenu *menu = contextMenu();
    int id = menu->idAt(0);
    menu->changeTitle(id, "Terminal sound control");
    KAction *helpAct = new KAction(i18n("&Help"), "help", KShortcut(), this, SLOT(popupHelp()),
        actionCollection(), "help" );
    KAction *aboutAct = new KAction(i18n("&About"), "about", KShortcut(), this, SLOT(popupAbout()),
        actionCollection(), "about" );
    helpAct->plug(menu);
    aboutAct->plug(menu);
}

mxsoundapplet::~mxsoundapplet()
{
}

void mxsoundapplet::popupHelp()
{
    KMessageBox::information(this, i18n("This applet does a connection to your terminal and start the mixer, to let you control the sound level."), i18n("Help") );
}

void mxsoundapplet::popupAbout()
{
    KAboutApplication kaa(m_about_data);
    kaa.exec();
}

void mxsoundapplet::mousePressEvent( QMouseEvent *e )
{
    if ( !rect().contains( e->pos() ) )
        return;
    KPopupMenu *menu = contextMenu();
    switch ( e->button() ) {
    case LeftButton:
        launchMixer();
        break;

    case MidButton:
        // fall through
        break;

    case RightButton:
        contextMenuAboutToShow( menu );
        menu->popup( e->globalPos() );
        break;

    default:
        // nothing
        break;
    }

}

void mxsoundapplet::launchMixer()
{
    QString bin_path = "/usr/bin/runlocal";

    //QString bin_path = "/usr/bin/gcalctool";
    QFileInfo fi = QString(bin_path);
    if ( !fi.exists() ) {
        KMessageBox::error(this, i18n("runlocal script is missing, please verify the installation.") );
        return;
    }
    
    QStringList list;
    list << bin_path << "alsamixergui";
    QProcess *q = new QProcess();
    q->setArguments( list );
    if (!q->start()){
        KMessageBox::error(this, i18n("Process is unable to start.") );
    } else {
        cout << "Command launched" << endl;
        KMessageBox::information(this, i18n("Connecting to terminal, and launching mixer, please wait."), i18n("Connecting..."), QString("isinformed") );
    }
    
}

#include "mxsoundapplet.moc"
